==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/bibtexcomment.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXCOMMENT_H
#define BIBTEXCOMMENT_H

#include <bibtexelement.h>

class BibTeXComment : public BibTeXElement
{
    Q_OBJECT
public:
    BibTeXComment( const QString &comment, QObject *parent = 0, const char *name = 0 );
    BibTeXComment( BibTeXComment *other );
    ~BibTeXComment();

    void setComment( const QString &comment );
    QString comment();

    QString toString( BibTeXFile::Format format = BibTeXFile::formatBibTeX, BibTeXFile::Encoding encoding = BibTeXFile::encImplicit );
    bool containsPattern( const QString& pattern, bool caseSensitive = false );

private:
    QString m_comment;
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexcomment.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXCOMMENT_H
#define BIBTEXCOMMENT_H

#include <bibtexelement.h>

namespace BibTeX
{

    class BibTeXComment : public BibTeXElement
    {
    public:
        BibTeXComment( const QString &text, bool usePercent = false );
        BibTeXComment( BibTeXComment *other );
        virtual ~BibTeXComment();

        QString text();
        void setText( const QString &text );
        bool usePercent();
        void setUsePercent( bool usePercent );

        bool containsPattern( const QString& pattern, bool caseSensitive = false );

    private:
        QString m_text;
        bool m_usePercent;
    };

}
#endif
